pub struct PythonOncePortRef { /* private fields */ }Trait Implementations
Sourceimpl Clone for PythonOncePortRef
impl Clone for PythonOncePortRef
Sourcefn clone(&self) -> PythonOncePortRef
fn clone(&self) -> PythonOncePortRef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PythonOncePortRef
impl Debug for PythonOncePortRef
Sourceimpl<'de> Deserialize<'de> for PythonOncePortRef
impl<'de> Deserialize<'de> for PythonOncePortRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<OncePortRef<PythonMessage>> for PythonOncePortRef
impl From<OncePortRef<PythonMessage>> for PythonOncePortRef
Sourcefn from(port_ref: OncePortRef<PythonMessage>) -> Self
fn from(port_ref: OncePortRef<PythonMessage>) -> Self
Converts to this type from the input type.
Sourceimpl<'py> IntoPyObject<'py> for PythonOncePortRef
impl<'py> IntoPyObject<'py> for PythonOncePortRef
Sourcetype Target = PythonOncePortRef
type Target = PythonOncePortRef
The Python output type
Sourcetype Output = Bound<'py, <PythonOncePortRef as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PythonOncePortRef as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for PythonOncePortRef
impl PartialEq for PythonOncePortRef
Sourceimpl PyClass for PythonOncePortRef
impl PyClass for PythonOncePortRef
Sourceimpl PyClassImpl for PythonOncePortRef
impl PyClassImpl for PythonOncePortRef
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PythonOncePortRef>
type ThreadChecker = SendablePyClass<PythonOncePortRef>
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForPythonOncePortRef
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PythonOncePortRef
impl PyClassNewTextSignature for PythonOncePortRef
const TEXT_SIGNATURE: &'static str = "(port)"
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder PythonOncePortRef
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder PythonOncePortRef
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder mut PythonOncePortRef
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder mut PythonOncePortRef
Sourceimpl PyTypeInfo for PythonOncePortRef
impl PyTypeInfo for PythonOncePortRef
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for PythonOncePortRef
impl Serialize for PythonOncePortRef
impl DerefToPyAny for PythonOncePortRef
impl StructuralPartialEq for PythonOncePortRef