pub struct PythonPortRef { /* private fields */ }Trait Implementations
Sourceimpl Clone for PythonPortRef
impl Clone for PythonPortRef
Sourcefn clone(&self) -> PythonPortRef
fn clone(&self) -> PythonPortRef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PythonPortRef
impl Debug for PythonPortRef
Sourceimpl<'de> Deserialize<'de> for PythonPortRef
impl<'de> Deserialize<'de> for PythonPortRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<PortRef<PythonMessage>> for PythonPortRef
impl From<PortRef<PythonMessage>> for PythonPortRef
Sourcefn from(port_ref: PortRef<PythonMessage>) -> Self
fn from(port_ref: PortRef<PythonMessage>) -> Self
Converts to this type from the input type.
Sourceimpl<'py> IntoPyObject<'py> for PythonPortRef
impl<'py> IntoPyObject<'py> for PythonPortRef
Sourcetype Target = PythonPortRef
type Target = PythonPortRef
The Python output type
Sourcetype Output = Bound<'py, <PythonPortRef as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PythonPortRef as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for PythonPortRef
impl PartialEq for PythonPortRef
Sourceimpl PyClass for PythonPortRef
impl PyClass for PythonPortRef
Sourceimpl PyClassImpl for PythonPortRef
impl PyClassImpl for PythonPortRef
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PythonPortRef>
type ThreadChecker = SendablePyClass<PythonPortRef>
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForPythonPortRef
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PythonPortRef
impl PyClassNewTextSignature for PythonPortRef
const TEXT_SIGNATURE: &'static str = "(port)"
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder PythonPortRef
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder PythonPortRef
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder mut PythonPortRef
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder mut PythonPortRef
Sourceimpl PyTypeInfo for PythonPortRef
impl PyTypeInfo for PythonPortRef
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for PythonPortRef
impl Serialize for PythonPortRef
impl DerefToPyAny for PythonPortRef
impl StructuralPartialEq for PythonPortRef